@@ -1,7 +1,8 @@
 import os
-from pyexcel_xlsx.xlsxw import XLSXWriter as Writer
-from pyexcel_xlsx.xlsxr import XLSXBook as Reader
+
 from base import PyexcelWriterBase, PyexcelHatWriterBase
+from pyexcel_xlsx import get_data
+from pyexcel_xlsx.xlsxw import XLSXWriter as Writer
 
 
 class TestNativeXLSXWriter:
@@ -9,20 +10,16 @@ class TestNativeXLSXWriter:
         self.content = {
             "Sheet1": [[1, 1, 1, 1], [2, 2, 2, 2], [3, 3, 3, 3]],
             "Sheet2": [[4, 4, 4, 4], [5, 5, 5, 5], [6, 6, 6, 6]],
-            "Sheet3": [[u'X', u'Y', u'Z'], [1, 4, 7], [2, 5, 8], [3, 6, 9]]
+            "Sheet3": [[u"X", u"Y", u"Z"], [1, 4, 7], [2, 5, 8], [3, 6, 9]],
         }
         self.testfile = "writer.xlsx"
-        writer = Writer()
-        writer.open(self.testfile)
+        writer = Writer(self.testfile, "xlsx")
         writer.write(self.content)
         writer.close()
-        reader = Reader()
-        reader.open(self.testfile)
-        content = reader.read_all()
+        content = get_data(self.testfile)
         for key in content.keys():
             content[key] = list(content[key])
         assert content == self.content
-        reader.close()
 
     def tearDown(self):
         if os.path.exists(self.testfile):
